@@ -12,7 +12,7 @@ use Alien::Build::Plugin::Download::Negotiate;
 use Alien::Build::Plugin::Extract::Negotiate;
 
 # ABSTRACT: Alien::Build plugin to download from GitHub
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 has github_user => sub { croak("github_user is required") };
@@ -22,15 +22,28 @@ has version => qr/^v?(.*)$/;
 has prefer => 0;
 has tags_only => 0;
 
+
+has asset => 0;
+has asset_name => qr/\.tar\.gz$/;
+has asset_format => 'tar.gz';
+has asset_convert_version => 0;
+
 my $once = 1;
 
 sub init
 {
   my($self, $meta) = @_;
 
-  if(defined $meta->prop->{start_url})
+  croak("Don't set set a start_url with the Download::GitHub plugin") if defined $meta->prop->{start_url};
+  croak("cannot use both asset and tag_only") if $self->asset && $self->tags_only;
+
+  if($self->asset)
   {
-    croak("Don't set set a start_url with the Download::GitHub plugin");
+    $meta->add_requires('configure' => 'Alien::Build::Plugin::Download::GitHub' => '0.09' );
+  }
+  else
+  {
+    $meta->add_requires('configure' => 'Alien::Build::Plugin::Download::GitHub' => 0 );
   }
 
   my $endpoint = $self->tags_only ? 'tags' : 'releases' ;
@@ -40,9 +53,19 @@ sub init
     prefer  => $self->prefer,
     version => $self->version,
   );
-  $meta->apply_plugin('Extract',
-    format  => 'tar.gz',
-  );
+
+  if($self->asset && $self->asset_format)
+  {
+    $meta->apply_plugin('Extract',
+      format  => $self->asset_format,
+    );
+  }
+  else
+  {
+    $meta->apply_plugin('Extract',
+      format  => 'tar.gz',
+    );
+  }
 
   my %gh_fetch_options;
   my $secret;
@@ -113,33 +136,68 @@ sub init
           }));
         }
 
-        my $res2 = {
-          type     => 'list',
-          list     => [
-            map {
-              my $release = $_;
-              my($version) = $release->{$version_key} =~ $self->version;
-              my @results = ({
-                filename => $release->{$version_key},
-                url      => $release->{tarball_url},
-                defined $version ? (version  => $version) : (),
-              });
+        my $res2;
 
-              if (my $include = $self->include_assets) {
-                my $filter = ref($include) eq 'Regexp' ? 1 : 0;
-                for my $asset(@{$release->{assets} || []}) {
-                  push @results, {
-                    asset_url => $asset->{url},
-                    filename  => $asset->{name},
-                    url       => $asset->{browser_download_url},
-                    defined $version ? (version  => $version) : (),
-                  } if (0 == $filter or $asset->{name} =~ $include);
-                }
+        if($self->asset)
+        {
+          $res2 = {
+            type => 'list',
+            list => [],
+          };
+
+          foreach my $release (@$rel)
+          {
+            foreach my $asset (@{ $release->{assets} })
+            {
+              if($asset->{name} =~ $self->asset_name)
+              {
+                push @{ $res2->{list} }, {
+                  filename => $asset->{name},
+                  url      => $asset->{browser_download_url},
+                  version  => $self->asset_convert_version ? $self->asset_convert_version->($release->{name}) : $release->{name},
+                };
               }
-              @results;
-            } @$rel
-          ],
-        };
+            }
+          }
+        }
+        else
+        {
+          $res2 = {
+            type     => 'list',
+            list     => [
+              map {
+                my $release = $_;
+                my($version) = $release->{$version_key} =~ $self->version;
+                my @results = ({
+                  filename => $release->{$version_key},
+                  url      => $release->{tarball_url},
+                  defined $version ? (version  => $version) : (),
+                });
+
+                if (my $include = $self->include_assets) {
+                  my $filter = ref($include) eq 'Regexp' ? 1 : 0;
+                  for my $asset(@{$release->{assets} || []}) {
+                    push @results, {
+                      asset_url => $asset->{url},
+                      filename  => $asset->{name},
+                      url       => $asset->{browser_download_url},
+                      defined $version ? (version  => $version) : (),
+                    } if (0 == $filter or $asset->{name} =~ $include);
+                  }
+                }
+                @results;
+              } @$rel
+            ],
+          };
+        }
+
+        if($ENV{ALIEN_BUILD_PLUGIN_DOWNLOAD_GITHUB_DEBUG})
+        {
+          require YAML;
+          $build->log(YAML::Dump({
+            res2 => $res2,
+          }));
+        }
 
         $res2->{protocol} = $res->{protocol} if exists $res->{protocol};
         return $res2;
@@ -177,7 +235,7 @@ Alien::Build::Plugin::Download::GitHub - Alien::Build plugin to download from Gi
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -212,6 +270,8 @@ The GitHub repository name.  This property is required.
 
 =head2 include_assets
 
+[deprecated: use the asset* properties instead]
+
 Defaulting to false, this option designates whether to include the assets of
 releases in the list of candidates for download. This should be one of three
 types of values:
@@ -269,6 +329,36 @@ GitHub repositories.  This is the default.
 
 =back
 
+=head2 asset
+
+Download from assets instead of via tag.  This option is incompatible with
+C<tags_only>.
+
+=head2 asset_name
+
+Regular expression which the asset name should match.  The default is C<qr/\.tar\.gz$/>.
+
+=head2 asset_format
+
+The format of the asset.  This is passed to L<Alien::Build::Plugin::Extract::Negotiate>
+so any format supported by that is valid.
+
+=head2 asset_convert_version
+
+This is an optional code reference which can be used to modify the version.  For example,
+if the release version is prefixed with a C<v> You could do this:
+
+ plugin 'Download::GitHub' => (
+   github_user => 'PerlAlien',
+   github_repo => 'dontpanic',
+   asset => 1,
+   asset_convert_version => sub {
+     my $version = shift;
+     $version =~ s/^v//;
+     $version;
+   },
+ );
+
 =head1 ENVIRONMENT
 
 =over 4
@@ -282,6 +372,11 @@ For security reasons, the PAT will be removed from the log.  Some Fetch plugins
 (for example the C<curl> plugin) will log HTTP requests headers so this will
 make sure that your PAT is not displayed in the log.
 
+=item ALIEN_BUILD_PLUGIN_DOWNLOAD_GITHUB_DEBUG
+
+Setting this to a true value will send additional diagnostics to the log during
+the indexing phase of the fetch.
+
 =back
 
 =head1 CAVEATS
